@@ -1,8 +1,5 @@
 package Term::ReadLine::Event;
-{
-  $Term::ReadLine::Event::VERSION = '0.04';
-}
-
+$Term::ReadLine::Event::VERSION = '0.05';
 use 5.006;
 use strict;
 use warnings;
@@ -87,6 +84,16 @@ sub with_IO_Async {
                                # ensure we're referring to the same value, this is
                                # a SCALAR ref.
                                my $ready = \ do{my $dummy};
+
+                               # Term::ReadLine::Gnu::XS relies on the fh being
+                               # able to do fileno.
+                               unless($fh->can('fileno')) {
+                                   require IO::Handle;
+                                   my $h = IO::Handle->new;
+                                   $h->fdopen($fh, 'r') or die "could not fdopen - $!";
+                                   $fh = $h
+                               }
+
                                $self->{loop}->add(
                                                   $self->{watcher} =
                                                   IO::Async::Handle->new(
@@ -263,13 +270,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Term::ReadLine::Event - Wrappers for Term::ReadLine's new event_loop model.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -507,7 +516,7 @@ Darin McBride <dmcbride@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Darin McBride and others.
+This software is copyright (c) 2015 by Darin McBride and others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
